@@ -12,18 +12,19 @@ unit_dict = {
     "frequency": "Hz",
     "revolution": "",
     "order": "",
-    "cr_band": "Bark",
+    "Critical band rate": "Bark",
     "speed": "rpm",
     "Rotation speed": "rpm",
     "modes": "",
 }
 
 axis_norm_dict = {
-    "time": ["angle_rotor"],
+    "time": ["angle_rotor", "speed"],
     "angle": ["tooth_id", "distance"],
     "freqs": ["elec_order", "mech_order"],
     "wavenumber": ["space_order"],
     "z": ["x L"],
+    "Critical band rate": ["Hz"],
 }
 
 norm_name_dict = {
@@ -34,6 +35,8 @@ norm_name_dict = {
     "angle_rotor": "Rotor mechanical angle",
     "tooth_id": "Stator tooth number",
     "x L": "x L",
+    "Hz": "Hz",
+    "speed": "speed",
 }
 
 norm_dict = {
@@ -47,6 +50,7 @@ norm_dict = {
     "Hz": "Frequency [Hz]",
     "Bark": "Critical band rate [Bark]",
     "time": "Time [s]",
+    "speed": "Rotation speed [rpm]",
 }
 
 axes_dict = {
