@@ -6,7 +6,8 @@ from matplotlib.backends.backend_qt5agg import (
     FigureCanvas,
     NavigationToolbar2QT as NavigationToolbar,
 )
-from SciDataTool.Functions.Plot.init_fig import init_fig, copy_fig
+from SciDataTool.Functions.Plot.init_fig import init_fig
+import matplotlib.pyplot as plt
 from matplotlib.lines import Line2D
 from matplotlib.patches import Rectangle
 from matplotlib.collections import PathCollection, QuadMesh
@@ -242,7 +243,7 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                 if annotations[ind[0]]._x == x:
                     X_str = annotations[ind[0]]._text
                     is_annot = False
-            else:
+            if is_annot:
                 # Use ticklabels
                 try:
                     x_float = float(self.ax.get_xticklabels()[-1]._text)
@@ -365,6 +366,7 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
             plot_obj = event.artist
             Z = None
             legend = None
+            annot = None
             if isinstance(plot_obj, Line2D):
                 ind = event.ind
                 xdata = plot_obj.get_xdata()
@@ -375,6 +377,18 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                     legend = self.ax.get_legend_handles_labels()[1][
                         self.ax.lines.index(plot_obj)
                     ]
+                    annotations = [
+                        child
+                        for child in self.ax.get_children()
+                        if isinstance(child, Annotation)
+                    ]
+                    if (
+                        annotations != []
+                        and self.ax.lines.index(plot_obj) in range(len(annotations))
+                        and not annotations[self.ax.lines.index(plot_obj)]._visible
+                        and "Overall" not in legend
+                    ):
+                        annot = annotations[self.ax.lines.index(plot_obj)]._text
             elif isinstance(plot_obj, PathCollection):
                 ind = event.ind
                 X = plot_obj.get_offsets().data[ind][0][0]
@@ -413,6 +427,8 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                 label = format_coord(X, Y, Z, sep="\n", ind=ind)
                 if legend is not None:
                     label = legend + "\n" + label
+                if annot is not None:
+                    label += "\n" + annot
                 if label != "":
                     if self.text is None:
                         # Create label in box and black cross
@@ -534,6 +550,13 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                             angle_str = "angle[smallestperiod]"
                         del plot_arg_dict_2D["is_smallestperiod"]
                     if "fig" in plot_arg_dict_2D:
+                        # plt.rcParams.update(
+                        #     {
+                        #         "font.family": plot_arg_dict_2D["fig"]
+                        #         .texts[0]
+                        #         ._fontproperties._family[0],
+                        #     }
+                        # )
                         del plot_arg_dict_2D["fig"]
                     self.data_orig.plot_2D_Data(
                         *[*[angle_str], *data_selection],
